/*
 *  gsetroot - gtk-based front-end for Esetroot
 *  Copyright (C) 2005 Bellabes Lounis
 *  nolius@users.sourceforge.net
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include <gtk/gtk.h>


void
on_button_open_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_apply_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_preview_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_info_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_window1_remove                      (GtkContainer    *container,
                                        GtkWidget       *widget,
                                        gpointer         user_data);
